@@ -160,7 +160,7 @@ process_events_component_to_server (CalBackendWCAP *wcap, ECalComponent *comp, g
 	icalcomponent *icalcomp;
 	icalproperty *prop;
 	icaltimezone *zone = NULL, *old_zone = NULL;
-	char *location = NULL;
+	const char *location = NULL;
 
 	if (allday)
 		*allday = FALSE;
