@@ -33,7 +33,7 @@ process_tasks_component_to_server (CalBackendWCAP *wcap, ECalComponent *comp, gb
 	icalcomponent *icalcomp;
 	icalproperty *prop;
 	icaltimezone *zone = NULL, *old_zone = NULL;
-	char *location = NULL;
+	const char *location = NULL;
 
 	/* Every task has a start time */
 	e_cal_component_get_dtstart (comp, &dt);
