@@ -604,7 +604,7 @@ cal_backend_wcap_get_rid_string (ECalComponent *comp)
 	e_cal_component_free_range (&range);
 
 	if (icaltime_is_valid_time (tt) && !icaltime_is_null_time (tt))
-		return icaltime_as_ical_string (tt);
+		return icaltime_as_ical_string_r (tt);
 	else
 		return g_strdup ("0");
 }
@@ -1360,7 +1360,7 @@ write_cache_when_idle (CalBackendWCAP *wcap)
 	icalcomponent_add_property (icalcomp, prop);
 
 	g_hash_table_foreach (priv->instances, build_calendar, icalcomp);
-	buf = icalcomponent_as_ical_string (icalcomp);
+	buf = icalcomponent_as_ical_string_r (icalcomp);
 	result = gnome_vfs_write (handle, buf, strlen (buf) * sizeof (char), &out);
 	g_free (buf);
 	icalcomponent_free (icalcomp);
@@ -1844,6 +1844,8 @@ go_online_with_thread (CalBackendWCAP *wcap, SunOneAccount *account)
 	sunone_connection_free_preferences (prefs);
 
 	priv->account_email_address = g_strdup (sunone_account_get_email (account));
+
+	read_cache (wcap);
 	
 	/* verify objects */
 	verify_components (wcap);
@@ -1965,7 +1967,6 @@ cal_backend_wcap_open (ECalBackendSync *backend, EDataCal *cal, gboolean only_if
 
 		return GNOME_Evolution_Calendar_Success;
 	}
-	read_cache (wcap);
 
 	thread = g_thread_create ((GThreadFunc)go_online, wcap, FALSE, &error);
 	if (!thread) {
@@ -2063,7 +2064,7 @@ cal_backend_wcap_send_objects (ECalBackendSync *backend, EDataCal *cal, const ch
 			*users = g_list_prepend (*users, tmp);
 	}
 	g_object_unref (comp);
-	*modified_calobj = icalcomponent_as_ical_string (top_level);
+	*modified_calobj = icalcomponent_as_ical_string_r (top_level);
  cleanup:	
 	icalcomponent_free (top_level);
 	
@@ -2171,7 +2172,7 @@ add_timezone (CalBackendWCAP *wcap, icalcomponent *icalcomp)
 	icaltimezone *zone;
 	icalcomponent *clone, *vcomp;
 	icalproperty *prop;
-	char *tzid;
+	const char *tzid;
 	
 	zone = icaltimezone_new ();
 	clone = icalcomponent_new_clone (icalcomp);
@@ -2216,7 +2217,7 @@ add_timezone (CalBackendWCAP *wcap, icalcomponent *icalcomp)
 		return GNOME_Evolution_Calendar_ObjectIdAlreadyExists;
 	}
 	
-	g_hash_table_insert (priv->timezones, tzid, zone);
+	g_hash_table_insert (priv->timezones, (gpointer)tzid, zone);
 
 	return GNOME_Evolution_Calendar_Success;
 }
@@ -2617,7 +2618,7 @@ cal_backend_wcap_get_timezone (ECalBackendSync *backend, EDataCal *cal,
 	if (!vtzcomp)
 		return GNOME_Evolution_Calendar_OtherError;
 
-	*object = icalcomponent_as_ical_string (vtzcomp);
+	*object = icalcomponent_as_ical_string_r (vtzcomp);
 	return GNOME_Evolution_Calendar_Success;
 }
 
