@@ -20,19 +20,8 @@
 #include "sunone-util.h"
 #include "sunone-message.h"
 
-gboolean jescs_verbose_debug = FALSE;
-gboolean jescs_long_debug = FALSE;
 #define RESPONSE_MAX_LENGTH 65535
 
-void sunone_message_init () 
-{
-	if (getenv ("EVOLUTION_JESCS_VERBOSE_DEBUG"))
-		jescs_verbose_debug = TRUE;
-	if (getenv ("EVOLUTION_JESCS_LONG_DEBUG"))
-		jescs_long_debug = TRUE;
-
-}
-
 SoupMessage *
 sunone_message_new_from_uri (SoupURI *suri, const char *method)
 {
@@ -61,68 +50,11 @@ sunone_message_new_full_from_uri (SoupURI *suri, const char *method,
 	return msg;
 }
 
-#ifdef SUNONE_DEBUG
-static void
-print_header (const char *name, const char *value, gpointer data)
-{
-	printf ("%s: %s\n", name, value);
-}
-
-static void
-sunone_debug_handler (SoupMessage *msg, gpointer user_data)
-{
-	if (jescs_verbose_debug) {
-		printf ("%d %s (%p @ %lu)\n", msg->status_code, msg->reason_phrase,
-			msg, time (0));
-		soup_message_headers_foreach (msg->response_headers,
-						print_header, NULL);
-		if (msg->response_body->length &&
-		    SUNONE_ERROR_IS_SUCCESSFUL (msg->status_code)) {
-			if (jescs_long_debug) {
-				printf ("\n%.*s\n", (int) msg->response_body->length,
-					msg->response_body->data);
-			} else {
-			    	if (msg->response_body->length < RESPONSE_MAX_LENGTH)
-					printf ("\n%.*s\n", (int) msg->response_body->length,
-						msg->response_body->data);
-			    	else 
-			    		printf ("\n%.*s\n", RESPONSE_MAX_LENGTH,
-						msg->response_body->data);
-			}
-		}
-		printf ("\n");
-	}
-}
-#endif
-
 void
 setup_message (SoupMessage *msg)
 {
 	soup_message_headers_append (msg->request_headers, "User-Agent",
 				 "Evolution/" EVOLUTION_VERSION);
-
-#ifdef SUNONE_DEBUG
-	if (jescs_verbose_debug)
-	{
-		const SoupURI *uri = soup_message_get_uri (msg);
-
-		printf ("%s %s%s%s HTTP/1.1 (%p @ %lu)\n",
-			msg->method, uri->path,
-			uri->query ? "?" : "",
-			uri->query ? uri->query : "",
-			msg, (unsigned long)time (0));
-		soup_message_headers_foreach (msg->request_headers,
-						print_header, NULL);
-		if (msg->request_body->length) {
-			printf ("\n%.*s\n", (int)msg->request_body->length,
-				msg->request_body->data);
-		}
-		printf ("\n");
-
-		g_signal_connect (msg, "got-headers",
-                  G_CALLBACK (sunone_debug_handler), NULL);
-	}
-#endif
 }
 
 void
