@@ -143,7 +143,7 @@ sunone_folder_tree_no_view ()
 	static GtkWidget *label = NULL;
 
 	if (!label) {
-		label = gtk_label_new (_("Cannot display this folder in this view.\n Please switch to Calendars/Tasks view to see the calendars/tasks.\n\n This view is used to create or delete calendar/tasks folders,\n manage folder permissions and subscriptions, show your invitations."));
+		label = gtk_label_new (_("To setup a new account, please goto Edit->Preferences->Mail accounts\nand select Sun Calendar WCAP as server type.\n\nThis view is used to create or delete calendar/tasks folders,\nmanage folder permissions and subscriptions, show your invitations.\nPlease switch to Calendars/Tasks view to see the calendars/tasks."));
 		gtk_label_set_justify ((GtkLabel *)label, GTK_JUSTIFY_CENTER);
 	}
 	g_object_ref (label);
@@ -598,8 +598,10 @@ static void render_pixbuf (GtkTreeViewColumn *column, GtkCellRenderer *renderer,
 	char *folder_type;
 
 	if (!initialised) {
-		folder_icons[FOLDER_ICON_NORMAL] = e_icon_factory_get_icon ("stock_normal", E_ICON_SIZE_MENU);
-		folder_icons[FOLDER_ICON_INVITATION] = e_icon_factory_get_icon ("stock_new-meeting", E_ICON_SIZE_MENU);
+		folder_icons[FOLDER_ICON_NORMAL] = e_icon_factory_get_icon ("stock_normal",
+				GTK_ICON_SIZE_MENU);
+		folder_icons[FOLDER_ICON_INVITATION] = e_icon_factory_get_icon ("stock_new-meeting",
+				GTK_ICON_SIZE_MENU);
 		initialised = TRUE;
 	}
 
