@@ -37,7 +37,7 @@ struct _SunOneInvitationListModelPrivate {
 	SunOneConnection *so_cnc;
 	GHashTable *invitations;
 	GList *invitations_list;
-	EConfigListener *config;
+	GConfClient *client;
 	gint timeout_id;
 	gint stamp;
 	char *uri;
@@ -79,13 +79,12 @@ sunone_invitation_list_model_class_init (SunOneInvitationListModelClass *klass)
 }
 
 static void
-key_changed_cb (EConfigListener *listener, const char *key, void *data)
+key_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer data)
 {
 	SunOneInvitationListModel *model = SUNONE_INVITATION_LIST_MODEL (data);
-	SunOneInvitationListModelPrivate *priv = model->priv;
 	char *location;
 	
-	location = e_config_listener_get_string_with_default (priv->config, "/apps/evolution/calendar/display/timezone", "UTC", NULL);
+	location = gconf_client_get_string (client, "/apps/evolution/calendar/display/timezone", NULL);
 	model->zone = icaltimezone_get_builtin_timezone (location);
 	g_free (location);
 
@@ -108,12 +107,16 @@ sunone_invitation_list_model_init (SunOneInvitationListModel *object)
 	priv->stamp = g_random_int ();
 	priv->invitations = g_hash_table_new (g_str_hash, g_str_equal);
 	priv->invitations_list = NULL;
-	priv->config = e_config_listener_new ();
-	g_signal_connect (G_OBJECT (priv->config), "key_changed", G_CALLBACK (key_changed_cb), model);
+	priv->client = gconf_client_get_default ();
+	gconf_client_notify_add (priv->client,
+			"/apps/evolution/calendar/display/timezone",
+			key_changed_cb, model,
+			NULL, NULL);
 	priv->timeout_id = -1;
 
 	model->account = NULL;
-	location = e_config_listener_get_string_with_default (priv->config, "/apps/evolution/calendar/display/timezone", "UTC", NULL);
+	location = gconf_client_get_string (priv->client,
+			"/apps/evolution/calendar/display/timezone", NULL);
 	model->zone = icaltimezone_get_builtin_timezone (location);
 	g_free (location);
 
@@ -151,9 +154,9 @@ sunone_invitation_list_model_dispose (GObject *object)
 			priv->calid = NULL;
 		}
 
-		if (priv->config) {
-			g_object_unref (G_OBJECT (priv->config));
-			priv->config = NULL;
+		if (priv->client) {
+			g_object_unref (G_OBJECT (priv->client));
+			priv->client = NULL;
 		}
 		
 		if (priv->timeout_id != -1) {
@@ -529,9 +532,14 @@ sunone_invitation_list_model_poll_cb (gpointer data)
 	if (!model->props)
 		goto removal;
 
-	if (!sunone_util_has_permissions (model->props, sunone_connection_get_user (cnc), 
-					  SUNONE_ACE_CONTEXT_CALENDAR_COMPONENTS, 
-					  SUNONE_ACE_PERMISSION_READ | SUNONE_ACE_PERMISSION_REPLY))
+	if (!sunone_util_has_permissions (model->props,
+					sunone_connection_get_user (cnc), 
+					SUNONE_ACE_CONTEXT_CALENDAR_COMPONENTS, 
+					SUNONE_ACE_PERMISSION_READ | SUNONE_ACE_PERMISSION_REPLY) &&
+				!sunone_util_has_permissions (model->props,
+					sunone_connection_get_uid (cnc),
+					SUNONE_ACE_CONTEXT_CALENDAR_COMPONENTS, 
+					SUNONE_ACE_PERMISSION_READ | SUNONE_ACE_PERMISSION_REPLY))
 		goto removal;
 
 	/* Now fetch the invitations */
@@ -718,9 +726,13 @@ sunone_invitation_list_model_set_value (SunOneInvitationListModel *model, int co
 		key = g_strconcat (priv->calid, ":calendar", NULL);
 		wcap = sunone_connection_get_wcap (cnc, key);
 		g_free (key);
-		if (wcap)
-			cal_backend_wcap_events_update_objects (E_CAL_BACKEND_SYNC (wcap), NULL,
-					icalcomponent_as_ical_string (clonecomp), CALOBJ_MOD_ALL, NULL, NULL);
+		if (wcap) {
+			char *string = icalcomponent_as_ical_string_r (clonecomp);
+
+			cal_backend_wcap_events_update_objects (E_CAL_BACKEND_SYNC (wcap),
+					NULL, string, CALOBJ_MOD_ALL, NULL, NULL);
+			g_free (string);
+		}
 		icalcomponent_free (clonecomp);
 	}
 }
