@@ -40,7 +40,7 @@
 #define USE_ITIP_VIEW 0
 
 struct _SunOneInvitationListPrivate {
-	EConfigListener *config;
+	GConfClient *client;
 	
 	SunOneInvitationListModel *model;	
 	
@@ -78,7 +78,7 @@ sunone_invitation_list_init (SunOneInvitationList *object)
 	list->priv = g_new0 (SunOneInvitationListPrivate, 1);
 	priv = list->priv;
 
-	priv->config = e_config_listener_new ();
+	priv->client = gconf_client_get_default ();
 	priv->model = NULL;
 	priv->treeview = NULL;
 	priv->pane = gtk_vpaned_new ();
@@ -101,7 +101,9 @@ sunone_invitation_list_init (SunOneInvitationList *object)
 	
 	gtk_paned_add2 (GTK_PANED (priv->pane), GTK_WIDGET (scroll));
 
-	pos = e_config_listener_get_long_with_default (priv->config, "/apps/evolution/evolution-jescs/invitationList/panePosition", 100, NULL);
+	pos = gconf_client_get_int (priv->client,
+			"/apps/evolution/evolution-jescs/invitationList/panePosition",
+			NULL);
 	gtk_paned_set_position (GTK_PANED (priv->pane), pos);
 
 	gtk_box_pack_start (GTK_BOX (list), priv->pane, TRUE, TRUE, 0);
@@ -116,12 +118,14 @@ sunone_invitation_list_destroy (GtkObject *object)
 	g_return_if_fail (IS_SUNONE_INVITATION_LIST (list));
 
 	if (priv) {
-		if (priv->config) {
+		if (priv->client) {
 			int pos = gtk_paned_get_position (GTK_PANED (priv->pane));
 			
-			e_config_listener_set_long (priv->config, "/apps/evolution/evolution-jescs/invitationList/panePosition", pos);
-			g_object_unref (G_OBJECT (priv->config));
-			priv->config = NULL;
+			gconf_client_set_int (priv->client,
+					"/apps/evolution/evolution-jescs/invitationList/panePosition",
+					pos, NULL);
+			g_object_unref (G_OBJECT (priv->client));
+			priv->client = NULL;
 		}
 		if (priv->model) {
 			/* Don't listen to model updates any more */
@@ -241,7 +245,7 @@ set_data_and_props (SunOneInvitationList *list, int row)
 
 	/* Send the icalendar code over */
 	top_level = toplevel_with_zones (list, comp);
-	string = icalcomponent_as_ical_string (top_level);
+	string = icalcomponent_as_ical_string_r (top_level);
 	set_data (BONOBO_WIDGET (priv->control), string);
 	g_free (string);
 	icalcomponent_free (top_level);
